/* tslint:disable:no-console */
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const benchmark_1 = require("benchmark");
const _ = require("lodash");
const rxjs_1 = require("rxjs");
const iterate_1 = require("./iterate");
const suite = new benchmark_1.Suite();
// Simulate iterating over a very lage Set of strings and applying a filter and a map on it
const hugeSet = new Set(new Array(10000).fill('file:///foo/bar'));
suite.add('Loop', () => {
    const result = new Set();
    for (const uri of hugeSet) {
        if (!uri.startsWith('file://')) {
            continue;
        }
        result.add(uri.substr('file:///'.length));
    }
});
suite.add('iterare', () => {
    iterate_1.iterate(hugeSet)
        .filter(uri => uri.startsWith('file://'))
        .map(uri => uri.substr('file:///'.length))
        .toSet();
});
suite.add('Array method chain', () => {
    return new Set(Array.from(hugeSet)
        .filter(uri => uri.startsWith('file://'))
        .map(uri => uri.substr('file:///'.length)));
});
suite.add('Lodash', () => {
    return new Set(
    // This uses lodash's lazy evaluation feature
    _(hugeSet)
        .filter((uri) => uri.startsWith('file://'))
        .map(uri => uri.substr('file:///'.length))
        .value());
});
suite.add('RxJS', (deferred) => {
    rxjs_1.Observable.from(Array.from(hugeSet))
        .filter((uri) => uri.startsWith('file://'))
        .map(uri => uri.substr('file:///'.length))
        .toArray()
        .subscribe(result => {
        deferred.resolve();
    });
}, { defer: true });
suite.on('cycle', (event) => {
    console.log(String(event.target));
});
suite.on('complete', function () {
    console.log('Fastest is ' + this.filter('fastest').map('name'));
});
suite.run({ async: true });
//# sourceMappingURL=benchmark.js.map